"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const SwaggerParser = require("swagger-parser");
const YAML = require("yamljs");
class Read extends command_1.Command {
    async run() {
        const { flags } = this.parse(Read);
        const { definition, format, dereference, validate } = flags;
        let method = SwaggerParser.parse;
        if (dereference) {
            method = SwaggerParser.dereference;
        }
        if (validate) {
            method = SwaggerParser.validate;
        }
        const output = await method.bind(SwaggerParser)(definition);
        if (format === 'json' || flags.json) {
            // JSON output
            this.log(JSON.stringify(output, null, 2));
        }
        else {
            // YAML output
            this.log(YAML.stringify(output, 99, 2));
        }
    }
}
Read.description = 'read, parse and convert OpenAPI definitions';
Read.examples = [
    `$ openapi read -d ./openapi.yml -f json > openapi.json`,
    '$ openapi read -d https://raw.githubusercontent.com/OAI/OpenAPI-Specification/master/examples/v3.0/petstore.yaml',
];
Read.flags = {
    help: command_1.flags.help({ char: 'h' }),
    definition: command_1.flags.string({ char: 'd', description: 'openapi definition file', required: true }),
    format: command_1.flags.enum({
        char: 'f',
        description: 'format',
        options: ['json', 'yaml', 'yml'],
        default: 'yaml',
        exclusive: ['json', 'yaml'],
    }),
    json: command_1.flags.boolean({ description: 'format as json (short for -f json)', exclusive: ['format', 'yaml'] }),
    yaml: command_1.flags.boolean({ description: 'format as yaml (short for -f yaml)', exclusive: ['format', 'json'] }),
    dereference: command_1.flags.boolean({ char: 'D', description: 'resolve $ref pointers' }),
    validate: command_1.flags.boolean({ char: 'V', description: 'validate against openapi schema' }),
};
Read.args = [];
exports.default = Read;
