"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const path = require("path");
const Koa = require("koa");
const Router = require("koa-router");
const serve = require("koa-static");
const swagger_ui_dist_1 = require("swagger-ui-dist");
const SwaggerParser = require("swagger-parser");
const command_1 = require("@oclif/command");
class SwaggerUI extends command_1.Command {
    async run() {
        const { flags } = this.parse(SwaggerUI);
        const { definition, port, url } = flags;
        const app = new Koa();
        const router = new Router();
        let document = null;
        if (definition) {
            router.get('/openapi.json', async (ctx) => {
                ctx.body = await SwaggerParser.parse(definition);
            });
            document = './openapi.json';
        }
        if (url) {
            document = url;
        }
        const swaggerUIRoot = swagger_ui_dist_1.getAbsoluteFSPath();
        if (document) {
            const indexHTML = fs.readFileSync(path.join(swaggerUIRoot, 'index.html')).toString('utf8');
            router.get('/', (ctx) => {
                ctx.body = indexHTML.replace('https://petstore.swagger.io/v2/swagger.json', document);
            });
        }
        app.use(router.routes());
        app.use(serve(swaggerUIRoot));
        const server = app.listen(port);
        process.on('disconnect', () => server.close());
        this.log(`Swagger UI running at http://localhost:${port}`);
    }
}
SwaggerUI.description = 'start a local Swagger UI instance';
SwaggerUI.examples = ['$ openapi swaggerui', '$ openapi swaggerui -d ./openapi.yml'];
SwaggerUI.flags = {
    help: command_1.flags.help({ char: 'h' }),
    definition: command_1.flags.string({ char: 'd', description: 'openapi definition file' }),
    url: command_1.flags.string({ char: 'u', description: 'openapi definition url' }),
    port: command_1.flags.integer({ char: 'p', description: 'port', default: 9000 }),
};
SwaggerUI.args = [];
exports.default = SwaggerUI;
